==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/ig-NG.pl <==
{
  am_pm_abbreviated => [
    "A.M.",
    "P.M."
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, MMM d, y G",
    GyMMMd => "MMM d, y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d, y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "ig-NG",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "M\N{U+1ecd}n",
    "Tiu",
    "Wen",
    "T\N{U+1ecd}\N{U+1ecd}",
    "Fra\N{U+1ecb}",
    "Sat",
    "\N{U+1ee4}ka"
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S"
  ],
  day_format_wide => [
    "M\N{U+1ecd}nde",
    "Tiuzdee",
    "Wenezdee",
    "T\N{U+1ecd}\N{U+1ecd}zdee",
    "Fra\N{U+1ecb}dee",
    "Sat\N{U+1ecd}dee",
    "Mb\N{U+1ecd}s\N{U+1ecb} \N{U+1ee4}ka"
  ],
  day_stand_alone_abbreviated => [
    "M\N{U+1ecd}n",
    "Tiu",
    "Wen",
    "T\N{U+1ecd}\N{U+1ecd}",
    "Fra\N{U+1ecb}",
    "Sat",
    "\N{U+1ee4}ka"
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S"
  ],
  day_stand_alone_wide => [
    "M\N{U+1ecd}nde",
    "Tiuzdee",
    "Wenezdee",
    "T\N{U+1ecd}\N{U+1ecd}zdee",
    "Fra\N{U+1ecb}dee",
    "Sat\N{U+1ecd}dee",
    "Mb\N{U+1ecd}s\N{U+1ecb} \N{U+1ee4}ka"
  ],
  era_abbreviated => [
    "T.K.",
    "A.K."
  ],
  era_narrow => [
    "T.K.",
    "A.K."
  ],
  era_wide => [
    "Tupu Kristi",
    "Af\N{U+1ecd} Kristi"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%A, %d %B %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%r",
  language => "Igbo",
  month_format_abbreviated => [
    "Jen",
    "Feb",
    "Maa",
    "Epr",
    "Mee",
    "Juu",
    "Jul",
    "\N{U+1ecc}g\N{U+1ecd}",
    "Sep",
    "\N{U+1ecc}kt",
    "Nov",
    "Dis"
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_format_wide => [
    "Jen\N{U+1ee5}war\N{U+1ecb}",
    "Febr\N{U+1ee5}war\N{U+1ecb}",
    "Maach\N{U+1ecb}",
    "Eprel",
    "Mee",
    "Juun",
    "Jula\N{U+1ecb}",
    "\N{U+1ecc}g\N{U+1ecd}\N{U+1ecd}st",
    "Septemba",
    "\N{U+1ecc}ktoba",
    "Novemba",
    "Disemba"
  ],
  month_stand_alone_abbreviated => [
    "Jen",
    "Feb",
    "Maa",
    "Epr",
    "Mee",
    "Juu",
    "Jul",
    "\N{U+1ecc}g\N{U+1ecd}",
    "Sep",
    "\N{U+1ecc}kt",
    "Nov",
    "Dis"
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_stand_alone_wide => [
    "Jen\N{U+1ee5}war\N{U+1ecb}",
    "Febr\N{U+1ee5}war\N{U+1ecb}",
    "Maach\N{U+1ecb}",
    "Eprel",
    "Mee",
    "Juun",
    "Jula\N{U+1ecb}",
    "\N{U+1ecc}g\N{U+1ecd}\N{U+1ecd}st",
    "Septemba",
    "\N{U+1ecc}ktoba",
    "Novemba",
    "Disemba"
  ],
  name => "Igbo Nigeria",
  native_language => "Igbo",
  native_name => "Igbo Nigeria",
  native_script => undef,
  native_territory => "Nigeria",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+1ecc}1",
    "\N{U+1ecc}2",
    "\N{U+1ecc}3",
    "\N{U+1ecc}4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "\N{U+1ecc}kara 1",
    "\N{U+1ecc}kara 2",
    "\N{U+1ecc}kara 3",
    "\N{U+1ecc}kara 4"
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+1ecc}1",
    "\N{U+1ecc}2",
    "\N{U+1ecc}3",
    "\N{U+1ecc}4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "\N{U+1ecc}kara 1",
    "\N{U+1ecc}kara 2",
    "\N{U+1ecc}kara 3",
    "\N{U+1ecc}kara 4"
  ],
  script => undef,
  territory => "Nigeria",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.24.tar.gz: DateTime-Locale-1.24/share/ig-NG.pl <==
{
  am_pm_abbreviated => [
    "A.M.",
    "P.M.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "MMM G y",
    GyMMMEd => "E, d MMM, G y",
    GyMMMd => "d MMM, G y",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ig-NG",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} 'na' {0}",
  datetime_format_long => "{1} 'na' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "M\N{U+1ecd}n",
    "Tiu",
    "Wen",
    "T\N{U+1ecd}\N{U+1ecd}",
    "Fra\N{U+1ecb}",
    "Sat\N{U+1ecd}dee",
    "\N{U+1ee4}ka",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "M\N{U+1ecd}nde",
    "Tiuzdee",
    "Wenezdee",
    "T\N{U+1ecd}\N{U+1ecd}zdee",
    "Fra\N{U+1ecb}dee",
    "Sat\N{U+1ecd}dee",
    "\N{U+1ee4}b\N{U+1ecd}ch\N{U+1ecb} \N{U+1ee4}ka",
  ],
  day_stand_alone_abbreviated => [
    "M\N{U+1ecd}n",
    "Tiu",
    "Wen",
    "T\N{U+1ecd}\N{U+1ecd}",
    "Fra\N{U+1ecb}",
    "Sat\N{U+1ecd}dee",
    "\N{U+1ee4}ka",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "M\N{U+1ecd}nde",
    "Tiuzdee",
    "Wenezdee",
    "T\N{U+1ecd}\N{U+1ecd}zdee",
    "Fra\N{U+1ecb}dee",
    "Sat\N{U+1ecd}dee",
    "\N{U+1ee4}b\N{U+1ecd}ch\N{U+1ecb} \N{U+1ee4}ka",
  ],
  era_abbreviated => [
    "T.K.",
    "A.K.",
  ],
  era_narrow => [
    "T.K.",
    "A.K.",
  ],
  era_wide => [
    "Tupu Kristi",
    "Af\N{U+1ecd} Kristi",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%A, %d %B %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%r",
  language => "Igbo",
  month_format_abbreviated => [
    "Jen",
    "Feb",
    "Maa",
    "Epr",
    "Mee",
    "Juu",
    "Jul",
    "\N{U+1ecc}g\N{U+1ecd}",
    "Sep",
    "\N{U+1ecc}kt",
    "Nov",
    "Dis",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "E",
    "M",
    "J",
    "J",
    "\N{U+1ecc}",
    "S",
    "\N{U+1ecc}",
    "N",
    "D",
  ],
  month_format_wide => [
    "Jen\N{U+1ee5}war\N{U+1ecb}",
    "Febr\N{U+1ee5}war\N{U+1ecb}",
    "Maach\N{U+1ecb}",
    "Epreel",
    "Mee",
    "Juun",
    "Jula\N{U+1ecb}",
    "\N{U+1ecc}g\N{U+1ecd}\N{U+1ecd}st",
    "Septemba",
    "\N{U+1ecc}ktoba",
    "Novemba",
    "Disemba",
  ],
  month_stand_alone_abbreviated => [
    "Jen",
    "Feb",
    "Maa",
    "Epr",
    "Mee",
    "Juu",
    "Jul",
    "\N{U+1ecc}g\N{U+1ecd}",
    "Sep",
    "\N{U+1ecc}kt",
    "Nov",
    "Dis",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "E",
    "M",
    "J",
    "J",
    "\N{U+1ecc}",
    "S",
    "\N{U+1ecc}",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Jen\N{U+1ee5}war\N{U+1ecb}",
    "Febr\N{U+1ee5}war\N{U+1ecb}",
    "Maach\N{U+1ecb}",
    "Epreel",
    "Mee",
    "Juun",
    "Jula\N{U+1ecb}",
    "\N{U+1ecc}g\N{U+1ecd}\N{U+1ecd}st",
    "Septemba",
    "\N{U+1ecc}ktoba",
    "Novemba",
    "Disemba",
  ],
  name => "Igbo Nigeria",
  native_language => "As\N{U+1ee5}s\N{U+1ee5} Igbo",
  native_name => "As\N{U+1ee5}s\N{U+1ee5} Igbo Na\N{U+1ecb}j\N{U+1ecb}r\N{U+1ecb}a",
  native_script => undef,
  native_territory => "Na\N{U+1ecb}j\N{U+1ecb}r\N{U+1ecb}a",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+1ecc}1",
    "\N{U+1ecc}2",
    "\N{U+1ecc}3",
    "\N{U+1ecc}4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+1ecc}kara 1",
    "\N{U+1ecc}kara 2",
    "\N{U+1ecc}kara 3",
    "\N{U+1ecc}kara 4",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+1ecc}1",
    "\N{U+1ecc}2",
    "\N{U+1ecc}3",
    "\N{U+1ecc}4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+1ecc}kara 1",
    "\N{U+1ecc}kara 2",
    "\N{U+1ecc}kara 3",
    "\N{U+1ecc}kara 4",
  ],
  script => undef,
  territory => "Nigeria",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 35,
}
